compare_tokenstreams

Function compare_tokenstreams 

pub fn compare_tokenstreams(
    first_tokenstream: &impl Display,
    second_tokenstream: &impl Display,
)
Panics

This function will panic if:

  • The token streams are not equal.
  • Either token stream is not valid Rust code.
  • rustfmt is not installed or is configured incorrectly.
  • It was not possible to create a child process to run rustfmt.
  • The output of rustfmt could not be converted to UTF-8.