compare_tokenstreams

Function compare_tokenstreams 

pub fn compare_tokenstreams(
    first_tokenstream: &impl ToString,
    second_tokenstream: &impl ToString,
)
Panics

This function will panic for different reasons:

  • The tokenstreams are not equal.
  • Any tokenstream is no valid rust code.
  • rustfmt is not installed or configured wrong.
  • It was not possible to create a child process to run rustfmt.
  • The output of rustfmt could not be converted to Utf-8.